@@ -9,6 +9,8 @@ from tendenci.core.perms.forms import TendenciBaseForm
 from tendenci.core.base.fields import SplitDateTimeField
 from django.template.defaultfilters import filesizeformat
 from django.utils.translation import ugettext_lazy as _
+from django.utils.safestring import mark_safe
+from django.core.urlresolvers import reverse
 
 from tendenci.addons.directories.models import Directory, DirectoryPricing
 from tendenci.addons.directories.utils import (get_payment_method_choices,
@@ -25,6 +27,11 @@ ALLOWED_LOGO_EXT = (
     '.png'
 )
 
+request_duration_defaults = {
+    'label': _('Requested Duration'),
+    'help_text': mark_safe('<a href="%s" id="add_id_pricing">Add Pricing Options</a>' % '/directories/pricing/add/'),
+}
+
 class DirectoryForm(TendenciBaseForm):
     body = forms.CharField(required=False,
         widget=TinyMCE(attrs={'style':'width:100%'},
@@ -43,9 +50,9 @@ class DirectoryForm(TendenciBaseForm):
 
     email = EmailVerificationField(label=_("Email"), required=False)
     email2 = EmailVerificationField(label=_("Email 2"), required=False)
-
-    pricing = forms.ModelChoiceField(label=_('Requested Duration'),
-                    queryset=DirectoryPricing.objects.filter(status=True).order_by('duration'))
+    
+    pricing = forms.ModelChoiceField(queryset=DirectoryPricing.objects.filter(status=True).order_by('duration'),
+                    **request_duration_defaults)
 
     class Meta:
         model = Directory
